@@ -16,14 +16,12 @@
 
 #![cfg_attr(not(feature = "std"), no_std)]
 //! A crate for polynomial commitment schemes.
-#![deny(unused_import_braces, unused_qualifications, trivial_casts)]
-#![deny(trivial_numeric_casts, private_in_public, variant_size_differences)]
-#![deny(stable_features, unreachable_pub, non_shorthand_field_patterns)]
-#![deny(unused_attributes, unused_mut)]
-#![deny(missing_docs)]
-#![deny(unused_imports)]
-#![deny(renamed_and_removed_lints, stable_features, unused_allocation)]
-#![deny(unused_comparisons, bare_trait_objects, unused_must_use, const_err)]
+#![deny(unused_import_braces, trivial_casts, bare_trait_objects)]
+#![deny(unused_qualifications, variant_size_differences, stable_features)]
+#![deny(non_shorthand_field_patterns, unused_attributes)]
+#![deny(renamed_and_removed_lints, unused_allocation, unused_comparisons)]
+#![deny(const_err, unused_must_use, unused_mut, private_in_public)]
+#![deny(unused_extern_crates, trivial_numeric_casts)]
 #![forbid(unsafe_code)]
 
 #[macro_use]
@@ -119,7 +117,9 @@ pub mod sonic_pc;
 /// `p` that have previously been committed to. Each element of a `QuerySet` is a `(label, query)`
 /// pair, where `label` is the label of a polynomial in `p`, and `query` is the field element
 /// that `p[label]` is to be queried at.
-pub type QuerySet<'a, F> = BTreeSet<(String, F)>;
+///
+/// Added the third field: the point name.
+pub type QuerySet<'a, T> = BTreeSet<(String, (String, T))>;
 
 /// `Evaluations` is the result of querying a set of labeled polynomials or equations
 /// `p` at a `QuerySet` `Q`. It maps each element of `Q` to the resulting evaluation.
@@ -256,13 +256,15 @@ pub trait PolynomialCommitment<F: Field>: Sized + Clone + Debug {
 
         let mut query_to_labels_map = BTreeMap::new();
 
-        for (label, point) in query_set.iter() {
-            let labels = query_to_labels_map.entry(point).or_insert_with(BTreeSet::new);
-            labels.insert(label);
+        for (label, (point_name, point)) in query_set.iter() {
+            let labels = query_to_labels_map
+                .entry(point_name)
+                .or_insert((point, BTreeSet::new()));
+            labels.1.insert(label);
         }
 
         let mut proofs = Vec::with_capacity(query_to_labels_map.len());
-        for (query, labels) in query_to_labels_map.into_iter() {
+        for (_point_name, (query, labels)) in query_to_labels_map.into_iter() {
             let mut query_polys = Vec::with_capacity(labels.len());
             let mut query_rands = Vec::with_capacity(labels.len());
             let mut query_comms = Vec::with_capacity(labels.len());
@@ -327,9 +329,11 @@ pub trait PolynomialCommitment<F: Field>: Sized + Clone + Debug {
     {
         let commitments: BTreeMap<_, _> = commitments.into_iter().map(|c| (c.label(), c)).collect();
         let mut query_to_labels_map = BTreeMap::new();
-        for (label, point) in query_set.iter() {
-            let labels = query_to_labels_map.entry(point).or_insert_with(BTreeSet::new);
-            labels.insert(label);
+        for (label, (point_name, point)) in query_set.iter() {
+            let labels = query_to_labels_map
+                .entry(point_name)
+                .or_insert((point, BTreeSet::new()));
+            labels.1.insert(label);
         }
 
         // Implicit assumption: proofs are order in same manner as queries in
@@ -338,7 +342,7 @@ pub trait PolynomialCommitment<F: Field>: Sized + Clone + Debug {
         assert_eq!(proofs.len(), query_to_labels_map.len());
 
         let mut result = true;
-        for ((query, labels), proof) in query_to_labels_map.into_iter().zip(proofs) {
+        for ((_point_name, (query, labels)), proof) in query_to_labels_map.into_iter().zip(proofs) {
             let mut comms: Vec<&'_ LabeledCommitment<_>> = Vec::with_capacity(labels.len());
             let mut values = Vec::with_capacity(labels.len());
             for label in labels.into_iter() {
@@ -424,9 +428,14 @@ pub trait PolynomialCommitment<F: Field>: Sized + Clone + Debug {
         let lc_s: BTreeMap<_, _> = linear_combinations.into_iter().map(|lc| (lc.label(), lc)).collect();
 
         let poly_query_set = lc_query_set_to_poly_query_set(lc_s.values().copied(), eqn_query_set);
-        let poly_evals: Evaluations<_> = poly_query_set.iter().cloned().zip(evals.clone().unwrap()).collect();
+        let poly_evals: Evaluations<_> = poly_query_set
+            .iter()
+            .map(|(_, point)| point)
+            .cloned()
+            .zip(evals.clone().unwrap())
+            .collect();
 
-        for &(ref lc_label, point) in eqn_query_set {
+        for &(ref lc_label, (_, point)) in eqn_query_set {
             if let Some(lc) = lc_s.get(lc_label) {
                 let claimed_rhs = *eqn_evaluations
                     .get(&(lc_label.clone(), point))
@@ -508,7 +517,7 @@ pub fn evaluate_query_set<'a, F: Field>(
 ) -> Evaluations<'a, F> {
     let polys: BTreeMap<_, _> = polys.into_iter().map(|p| (p.label(), p)).collect();
     let mut evaluations = Evaluations::new();
-    for (label, point) in query_set {
+    for (label, (_point_name, point)) in query_set {
         let poly = polys.get(label).expect("polynomial in evaluated lc is not found");
         let eval = poly.evaluate(*point);
         evaluations.insert((label.clone(), *point), eval);
@@ -523,11 +532,11 @@ fn lc_query_set_to_poly_query_set<'a, F: 'a + Field>(
     let mut poly_query_set = QuerySet::new();
     let lc_s = linear_combinations.into_iter().map(|lc| (lc.label(), lc));
     let linear_combinations: BTreeMap<_, _> = lc_s.collect();
-    for (lc_label, point) in query_set {
+    for (lc_label, (point_name, point)) in query_set {
         if let Some(lc) = linear_combinations.get(lc_label) {
             for (_, poly_label) in lc.iter().filter(|(_, l)| !l.is_one()) {
                 if let LCTerm::PolyLabel(l) = poly_label {
-                    poly_query_set.insert((l.into(), *point));
+                    poly_query_set.insert((l.into(), (point_name.clone(), *point)));
                 }
             }
         }
@@ -603,7 +612,7 @@ pub mod tests {
             let mut values = Evaluations::new();
             let point = F::rand(rng);
             for (i, label) in labels.iter().enumerate() {
-                query_set.insert((label.clone(), point));
+                query_set.insert((label.clone(), ("rand".into(), point)));
                 let value = polynomials[i].evaluate(point);
                 values.insert((label.clone(), point), value);
             }
@@ -699,10 +708,10 @@ pub mod tests {
             let mut query_set = QuerySet::new();
             let mut values = Evaluations::new();
             // let mut point = F::one();
-            for _ in 0..num_points_in_query_set {
+            for point_id in 0..num_points_in_query_set {
                 let point = F::rand(rng);
                 for (i, label) in labels.iter().enumerate() {
-                    query_set.insert((label.clone(), point));
+                    query_set.insert((label.clone(), (format!("rand_{}", point_id), point)));
                     let value = polynomials[i].evaluate(point);
                     values.insert((label.clone(), point), value);
                 }
@@ -857,7 +866,7 @@ pub mod tests {
                     if !lc.is_empty() {
                         linear_combinations.push(lc);
                         // Insert query
-                        query_set.insert((label.clone(), point));
+                        query_set.insert((label.clone(), (format!("rand_{}", i), point)));
                     }
                 }
             }
